<div class="footer-container">
    <div class="footer-columns">
        <div class="fc1 footer-col">
            <?php $aurora_lite_footer_logo_url = aurora_lite_show_logo('footer'); if ( $aurora_lite_footer_logo_url ) : ?>
            <img src="<?php echo $aurora_lite_footer_logo_url; ?>" alt="<?php bloginfo('name'); ?>" class="footer-logo">
            <?php endif; ?>
            <?php aurora_lite_footer_bio();
            aurora_lite_show_footer_socials() ?>
        </div>
        <div class="fc2 footer-col">
            <h4><?php aurora_lite_footer_col_title(2);?></h4>
            <?php aurora_lite_footer_menu('footer1'); ?>
        </div>

        <div class="fc3 footer-col">
            <h4><?php aurora_lite_footer_col_title(3);?></h4>
            <?php aurora_lite_footer_menu('footer2'); ?>
        </div>

        <div class="fc4 footer-col">
            <h4><?php aurora_lite_footer_col_title(4);?></h4>
            <?php aurora_lite_footer_menu('footer3'); ?>
        </div>

    </div>

    <div class="footer-bottom">
        <div class="footer-copyright"><?php echo aurora_lite_copyright_text();?></div>
        <div class="footer-bottom-menu"><?php aurora_lite_footer_menu( 'footerbottom' );?></div>
    </div>
</div>